@@ -13,12 +13,12 @@
 #include <QMouseEvent>
 
 // KDEGames
-#include <KgSound>
+#include <KGameSound>
 
 // Bomber
 #include "board.h"
 
-class KgThemeProvider;
+class KGameThemeProvider;
 
 /**
  * This is the main game widget class. It manages things like the lives, source counts and game states.
@@ -38,7 +38,7 @@ public:
                        Suspended,
                        GameOver };
 
-    explicit BomberGameWidget(KgThemeProvider * provider, QWidget * parent = nullptr);
+    explicit BomberGameWidget(KGameThemeProvider * provider, QWidget * parent = nullptr);
     ~BomberGameWidget() override;
 
     /**
@@ -190,8 +190,8 @@ private:
 
     QGraphicsPixmapItem * m_overlay;
 
-    KgSound m_soundBomb;
-    KgSound m_soundCrash;
+    KGameSound m_soundBomb;
+    KGameSound m_soundCrash;
 };
 
 #endif
